#define XERR
#include "loop.ih"

void Loop::setStatus(Status status, double age)
{
    d_status = status;
    d_deathAge = age;
}
